<?php

namespace App\Factory;

use App\Exception;

class PaymentFactory {
    
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function getReceiptType ($receipt) {
        $sql = "
            SELECT CDTIPORECE
              
              FROM TIPORECEINTE TP
             
              JOIN INTEGRACAO INTE 
                ON TP.CDINTEGRACAO = INTE.CDINTEGRACAO
            
             WHERE INTE.IDINTEGRACAO = :IDINTEGRACAO
               AND UPPER(REPLACE(CDTPRECEINTE, ' ', '')) = :CDTPRECEINTE";
        
        $params = [
            ":CDTPRECEINTE" => strtoupper(preg_replace("/\s+/", "", $receipt)),
            ":IDINTEGRACAO" => "ORD"
        ];
        
        $result = $this->connection->fetchAll($sql, $params);
        
        if (empty($result)) 
            throw new Exception\ParamsException("O método de pagamento ($receipt) não está relacionado a um tipo de recebimento válido Teknisa");
        
        if (!isset($result[0]["CDTIPORECE"])) 
            throw new Exception\ParamsException("O método de pagamento ($receipt) não está relacionado a um tipo de recebimento válido Teknisa");
        
        return $result[0]["CDTIPORECE"];
    }
    
    public function getMoneyReceiptCode () {
        $sql = "SELECT MIN(CDTIPORECE) AS CDTIPORECE
                  FROM TIPORECE
                 WHERE IDTIPORECE = '4'";
        
        $result = $this->connection->fetchAll($sql);
        
        return $result[0]["CDTIPORECE"];
    }
    
     public function getPersonalCreditReceiptCode ($receiptType) {
        $sql = "
            SELECT CDTIPORECE FROM TIPORECE
                WHERE IDTIPORECE = '9'
               AND CDTIPORECE = :CDTIPORECE
        ";
        
        $params = [
            ":CDTIPORECE" => $receiptType
                ];
        $result = $this->connection->fetchAll($sql,$params);
        if (count($result) == 0) {
            return null;
        }
        return $result[0]["CDTIPORECE"];
     }
}
